import { 
  select, 
  csv,
  event,
  brushX,
  max,
  range,
  scaleLinear, 
  scaleTime,
  scaleOrdinal,
  schemeCategory10,
  timeParse, 
  timeFormat, 
  extent,
  axisLeft,
  axisBottom,
  line,
  nest
} from 'd3';

const width = 960;
const height = 400;
const margin = { top: 10, bottom: 15, right: 20, left:50};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

export const displayChart = (selection,props) => {
  const {width,
         height,
         circleRadius,
         xAxisLabel,
         yAxisLabel,
         colorValue,
         brushed
        } = props;
  let { data } = props;
  const yScale = scaleLinear()
    .domain(extent(data, d => d.value))
    .range([innerHeight, 0]);
  const xScale = scaleTime()
    .domain(extent(data, d => d.Date))
    .range([0,innerWidth]);
  const colorScale = scaleOrdinal(schemeCategory10);
  const focus = selection.append('g')
    .attr('class', 'focus')
    .attr('transform', `translate(${margin.left},${margin.top})`);

  const xValue = d => d.Date;
  const yValue = d => d.value;
    
  const yAxis = axisLeft(yScale);
  const xAxis = axisBottom(xScale);  
   
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)));
   
  const nested = nest()
    .key(colorValue)
    .entries(data);
 
  colorScale.domain(nested.map(d => d.key));
  
  const yAxisG = focus.append('g')
    .attr('class', 'y-axis');
  yAxisG.call(yAxis);
  
  const xAxisG = focus.append('g')
    .attr('class', 'x-axis')
    .attr('transform', `translate(0,${innerHeight})`);
  xAxisG.call(xAxis);
  
  xAxisG.append('text')
    .attr('class', 'x-axis-label')
    .attr('y', 35)
    .attr('x', innerWidth/2)
    .attr('fill', 'black')
    .text(xAxisLabel)
  

  yAxisG.append('text')
    .attr("transform", "rotate(-90)")
    .attr('class', 'y-axis-label')
    .attr('y', -30)
    .attr('x', -innerHeight/2)
    .attr('fill', 'black')
    .attr('text-anchor','middle')
    .text(yAxisLabel)
  
  selection.append("defs").append("clipPath")
    .attr("id", "clip")
  .append("rect")
    .attr("width", width)
    .attr("height", height);
  
  focus.selectAll('.line-path').data(nested)
    .enter().append('path')
    .attr('class', 'line-path')
    .attr('d', d => lineGenerator(d.values))
    .attr('stroke', d => colorScale(d.key));
  
  focus.selectAll('.circle-focus').data(data)
    .attr("clip-path", "url(#clip)")
  .enter().append('circle')
    .attr('class','circle-focus')
    .attr('cx', d => xScale(xValue(d)))
    .attr('cy', d => yScale(yValue(d)))
    .attr('r', circleRadius);
  
}